@@ -131,12 +131,13 @@ class Api(object):
             return wrapper
 
         # Must be instance of ResourceView
-        assert issubclass(resource, ResourceView), \
-            "{0} not subclass of ResourceView".format(resource)
+        if not issubclass(resource, ResourceView):
+            raise AssertionError("%s not subclass of ResourceView" % resource)
 
         # Cannot be abstract
-        assert not resource._meta.abstract, \
-            "Attempt register of abstract resource: {0}.".format(resource)
+        if resource._meta.abstract:
+            raise AssertionError("Attempt register of abstract resource: %s."
+                                 % resource)
 
         # Fabric of resources
         meta = dict(self.meta, **meta)
@@ -150,15 +151,17 @@ class Api(object):
 
         params['__doc__'] = resource.__doc__
 
-        resource = type('%s%s' % (
-            resource.__name__, len(self.resources)), (resource,), params)
+        new_resource = type(
+            '%s%s' % (resource.__name__, len(self.resources)),
+            (resource,), params)
 
-        if self.resources.get(resource._meta.url_name):
+        if self.resources.get(new_resource._meta.url_name):
             logger.warning(
                 "A resource '%r' is replacing the existing record for '%s'",
-                resource, self.resources.get(resource._meta.url_name))
+                new_resource, self.resources.get(new_resource._meta.url_name))
+
+        self.resources[new_resource._meta.url_name] = new_resource
 
-        self.resources[resource._meta.url_name] = resource
         return resource
 
     @property
